==> open-xchange-core_7.6.1.orig.tar.bz2: open-xchange-core-7.6.1/com.openexchange.mail.autoconfig/src/com/openexchange/mail/autoconfig/IndividualAutoconfig.java <==
package com.openexchange.mail.autoconfig;


/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * {@link IndividualAutoconfig}
 *
 * @author <a href="mailto:martin.herfurth@open-xchange.com">Martin Herfurth</a>
 */
public class IndividualAutoconfig extends Autoconfig {

    private final Autoconfig delegate;
    private String individualUsername;

    public IndividualAutoconfig(Autoconfig autoconfig) {
        super();
        this.delegate = autoconfig;
    }

    @Override
    public int hashCode() {
        return delegate.hashCode();
    }

    @Override
    public String getMailServer() {
        return delegate.getMailServer();
    }

    @Override
    public void setMailServer(String mailServer) {
        delegate.setMailServer(mailServer);
    }

    @Override
    public String getTransportServer() {
        return delegate.getTransportServer();
    }

    @Override
    public void setTransportServer(String transportServer) {
        delegate.setTransportServer(transportServer);
    }

    @Override
    public String getMailProtocol() {
        return delegate.getMailProtocol();
    }

    @Override
    public void setMailProtocol(String mailProtocol) {
        delegate.setMailProtocol(mailProtocol);
    }

    @Override
    public boolean equals(Object obj) {
        return delegate.equals(obj);
    }

    @Override
    public String getTransportProtocol() {
        return delegate.getTransportProtocol();
    }

    @Override
    public void setTransportProtocol(String transportProtocol) {
        delegate.setTransportProtocol(transportProtocol);
    }

    @Override
    public Integer getMailPort() {
        return delegate.getMailPort();
    }

    @Override
    public void setMailPort(int mailPort) {
        delegate.setMailPort(mailPort);
    }

    @Override
    public Integer getTransportPort() {
        return delegate.getTransportPort();
    }

    @Override
    public void setTransportPort(int transportPort) {
        delegate.setTransportPort(transportPort);
    }

    @Override
    public Boolean isMailSecure() {
        return delegate.isMailSecure();
    }

    @Override
    public void setMailSecure(boolean mailSecure) {
        delegate.setMailSecure(mailSecure);
    }

    @Override
    public Boolean isTransportSecure() {
        return delegate.isTransportSecure();
    }

    @Override
    public void setTransportSecure(boolean transportSecure) {
        delegate.setTransportSecure(transportSecure);
    }

    @Override
    public String getUsername() {
        return individualUsername;
    }

    @Override
    public void setUsername(String username) {
        individualUsername = username;
    }

    @Override
    public String toString() {
        return delegate.toString();
    }

}

==> open-xchange-core_7.8.2.orig.tar.bz2: open-xchange-core-7.8.2/com.openexchange.mail.autoconfig/src/com/openexchange/mail/autoconfig/IndividualAutoconfig.java <==
package com.openexchange.mail.autoconfig;


/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * {@link IndividualAutoconfig}
 *
 * @author <a href="mailto:martin.herfurth@open-xchange.com">Martin Herfurth</a>
 */
public class IndividualAutoconfig extends Autoconfig {

    private final Autoconfig delegate;
    private String individualUsername;

    public IndividualAutoconfig(Autoconfig autoconfig) {
        super();
        this.delegate = autoconfig;
    }

    @Override
    public int hashCode() {
        return delegate.hashCode();
    }

    @Override
    public String getMailServer() {
        return delegate.getMailServer();
    }

    @Override
    public void setMailServer(String mailServer) {
        delegate.setMailServer(mailServer);
    }

    @Override
    public String getTransportServer() {
        return delegate.getTransportServer();
    }

    @Override
    public void setTransportServer(String transportServer) {
        delegate.setTransportServer(transportServer);
    }

    @Override
    public String getMailProtocol() {
        return delegate.getMailProtocol();
    }

    @Override
    public void setMailProtocol(String mailProtocol) {
        delegate.setMailProtocol(mailProtocol);
    }

    @Override
    public boolean equals(Object obj) {
        return delegate.equals(obj);
    }

    @Override
    public String getTransportProtocol() {
        return delegate.getTransportProtocol();
    }

    @Override
    public void setTransportProtocol(String transportProtocol) {
        delegate.setTransportProtocol(transportProtocol);
    }

    @Override
    public Integer getMailPort() {
        return delegate.getMailPort();
    }

    @Override
    public void setMailPort(int mailPort) {
        delegate.setMailPort(mailPort);
    }

    @Override
    public Integer getTransportPort() {
        return delegate.getTransportPort();
    }

    @Override
    public void setTransportPort(int transportPort) {
        delegate.setTransportPort(transportPort);
    }

    @Override
    public Boolean isMailSecure() {
        return delegate.isMailSecure();
    }

    @Override
    public void setMailSecure(boolean mailSecure) {
        delegate.setMailSecure(mailSecure);
    }

    @Override
    public Boolean isTransportSecure() {
        return delegate.isTransportSecure();
    }

    @Override
    public void setTransportSecure(boolean transportSecure) {
        delegate.setTransportSecure(transportSecure);
    }

    @Override
    public String getUsername() {
        return individualUsername;
    }

    @Override
    public void setUsername(String username) {
        individualUsername = username;
    }

    @Override
    public String toString() {
        return delegate.toString();
    }

}
